@@ -227,12 +227,12 @@ bool WandererCover::Handshake()
 
 void WandererCover::updateCoverStatus(char* res)
 {
-    if (strcmp(res, "0") == 0)
+    if (strcmp(res, "0") == 0 && isCoverOpen == true)
     {
         isCoverOpen = false;
         setParkCapStatusAsClosed();
     }
-    else if (strcmp(res, "1") == 0)
+    else if (strcmp(res, "1") == 0 && isCoverOpen == false)
     {
         isCoverOpen = true;
         setParkCapStatusAsOpen();
@@ -365,7 +365,7 @@ bool WandererCover::getStartupData()
 IPState WandererCover::ParkCap()
 {
     LOG_DEBUG("=== Starting ParkCap() - Attempting to close dust cap ===");
-    
+
     LOGF_DEBUG("Checking number of steps: %d", NumberOfStepsBeetweenOpenAndCloseState);
     if (NumberOfStepsBeetweenOpenAndCloseState == 0)
     {
@@ -548,8 +548,8 @@ bool WandererCover::SetLightBoxBrightness(uint16_t value)
         return true;
     }
     char response[WANDERER_RESPONSE_SIZE];
-    char command[3] = {0};
-    snprintf(command, 3, "%03d\n", value);
+    char command[5] = {0};
+    snprintf(command, 5, "%03d\n", value);
     if (!sendCommand(command, response, false))
         return false;
 
@@ -613,7 +613,9 @@ void WandererCover::setLightBoxBrightnesStatusToValue(uint16_t value)
     if (value == 0)
     {
         setLightBoxStatusAsSwitchedOff();
-    } else {
+    }
+    else
+    {
         IUSaveText(&StatusT[1], "On");
         IDSetText(&StatusTP, nullptr);
         LightSP[0].setState(ISS_ON);
@@ -775,6 +777,11 @@ bool WandererCover::processConfigurationButtonSwitch(const char *dev, const char
     return false;
 }
 
+void WandererCover::TimerHit()
+{
+    SetTimer(getPollingPeriod());
+}
+
 bool WandererCover::hasWandererSentAnError(char* response)
 {
     const std::string response_string( response );
