@@ -73,14 +73,19 @@ bool Communication::sendRequest(const json &command, json *response)
     if (response == nullptr)
         return true;
 
-    char read_buf[DRIVER_LEN] = {0};
-    if ( (tty_rc = tty_read_section(m_PortFD, read_buf, DRIVER_STOP_CHAR, DRIVER_TIMEOUT, &nbytes_read)) != TTY_OK)
+    char read_buf[DRIVER_LEN];
+    do
     {
-        char errorMessage[MAXRBUF] = {0};
-        tty_error_msg(tty_rc, errorMessage, MAXRBUF);
-        LOGF_ERROR("Serial write error: %s", errorMessage);
-        return false;
+        memset(read_buf, 0, sizeof(read_buf));
+        if ( (tty_rc = tty_read_section(m_PortFD, read_buf, DRIVER_STOP_CHAR, DRIVER_TIMEOUT, &nbytes_read)) != TTY_OK)
+        {
+            char errorMessage[MAXRBUF] = {0};
+            tty_error_msg(tty_rc, errorMessage, MAXRBUF);
+            LOGF_ERROR("Serial write error: %s", errorMessage);
+            return false;
+        }
     }
+    while (strncmp(read_buf, "ERR:", 4) == 0 && (LOGF_WARN("%s", read_buf), true));
 
     LOGF_DEBUG("<RES> %s", read_buf);
 
@@ -88,7 +93,7 @@ bool Communication::sendRequest(const json &command, json *response)
     {
         if (strstr(read_buf, "Error:"))
         {
-            LOGF_ERROR("Requred %s failed: %s", command.dump().c_str(), read_buf);
+            LOGF_ERROR("Required %s failed: %s", command.dump().c_str(), read_buf);
             return false;
         }
         *response = json::parse(read_buf)["res"];
@@ -103,7 +108,7 @@ bool Communication::sendRequest(const json &command, json *response)
     return true;
 }
 
-bool Communication::getStringAsDouble(MotorType type, const std::string &parameter, double &value)
+bool Communication::getStringAsDouble(NodeType type, const std::string &parameter, double &value)
 {
     std::string response;
     if (get(type, parameter, response))
@@ -114,54 +119,54 @@ bool Communication::getStringAsDouble(MotorType type, const std::string &paramet
     return false;
 }
 
-template <typename T> bool Communication::get(MotorType type, const std::string &parameter, T &value)
+template <typename T> bool Communication::get(NodeType type, const std::string &parameter, T &value)
 {
-    std::string motor;
+    std::string node;
     switch (type)
     {
         case MOT_1:
-            motor = "MOT1";
+            node = "MOT1";
             break;
         case MOT_2:
-            motor = "MOT2";
+            node = "MOT2";
             break;
         default:
             break;
     }
 
     json jsonRequest = {{parameter, ""}};
-    return genericRequest(motor, "get", jsonRequest, &value);
+    return genericRequest(node, "get", jsonRequest, &value);
 }
 
-bool Communication::set(MotorType type, const json &value)
+bool Communication::set(NodeType type, const json &value)
 {
-    std::string motor;
+    std::string node;
     switch (type)
     {
         case MOT_1:
-            motor = "MOT1";
+            node = "MOT1";
             break;
         case MOT_2:
-            motor = "MOT2";
+            node = "MOT2";
             break;
         default:
             break;
     }
 
     std::string isDone;
-    if (genericRequest(motor, "set", value, &isDone))
+    if (genericRequest(node, "set", value, &isDone))
         return isDone == "done";
     return false;
 }
 
-template <typename T> bool Communication::genericRequest(const std::string &motor, const std::string &type,
+template <typename T> bool Communication::genericRequest(const std::string &node, const std::string &type,
         const json &command, T *response)
 {
     json jsonRequest;
-    if (motor.empty())
+    if (node.empty())
         jsonRequest = {{"req", {{type, command}}}};
     else
-        jsonRequest = {{"req", {{type, {{motor, command}}}}}};
+        jsonRequest = {{"req", {{type, {{node, command}}}}}};
     if (response == nullptr)
         return sendRequest(jsonRequest);
     else
@@ -178,10 +183,30 @@ template <typename T> bool Communication::genericRequest(const std::string &moto
             //                key = oneItem.key();
             try
             {
-                if (motor.empty())
-                    jsonResponse[type][key].get_to(*response);
+                if (node.empty())
+                {
+                    if (jsonResponse[type].contains(key))
+                        jsonResponse[type][key].get_to(*response);
+                    else if (jsonResponse[type].contains("ERROR"))
+                    {
+                        std::string error = jsonResponse[type]["ERROR"];
+                        LOGF_ERROR("Error: %s", error.c_str());
+                        return false;
+                    }
+                }
                 else
-                    jsonResponse[type][motor][key].get_to(*response);
+                {
+                    if (jsonResponse[type][node].contains(key))
+                        jsonResponse[type][node][key].get_to(*response);
+                    else if (jsonResponse[type][node].contains("ERROR"))
+                    {
+                        std::string error = jsonResponse[type][node]["ERROR"];
+                        LOGF_ERROR("Error: %s", error.c_str());
+                        return false;
+                    }
+                }
+
+
             }
             catch (json::exception &e)
             {
@@ -198,22 +223,22 @@ template <typename T> bool Communication::genericRequest(const std::string &moto
     return false;
 }
 
-template <typename T> bool Communication::command(MotorType type, const json &jsonCommand)
+template <typename T> bool Communication::command(NodeType type, const json &jsonCommand)
 {
-    std::string motor;
+    std::string node;
     switch (type)
     {
         case MOT_1:
-            motor = "MOT1";
+            node = "MOT1";
             break;
         case MOT_2:
-            motor = "MOT2";
+            node = "MOT2";
             break;
         default:
             break;
     }
     std::string response;
-    if (genericRequest(motor, "cmd", jsonCommand, &response))
+    if (genericRequest(node, "cmd", jsonCommand, &response))
         return response == "done";
     return false;
 }
@@ -231,7 +256,7 @@ Focuser::Focuser(const std::string &name, int port)
 *******************************************************************************************************/
 bool Focuser::goAbsolutePosition(uint32_t position)
 {
-    return m_Communication->command(MOT_1, {{"MOVE_ABS", {{"STEPS", position}}}});
+    return m_Communication->command(MOT_1, {{"MOVE_ABS", {{"STEP", position}}}});
 }
 
 /******************************************************************************************************
@@ -330,7 +355,7 @@ bool Focuser::getMotorTemp(double &value)
 *******************************************************************************************************/
 bool Focuser::getExternalTemp(double &value)
 {
-    return m_Communication->getStringAsDouble(MOT_NONE, "EXT_T", value);
+    return m_Communication->getStringAsDouble(GENERIC_NODE, "EXT_T", value);
 }
 
 /******************************************************************************************************
@@ -338,7 +363,7 @@ bool Focuser::getExternalTemp(double &value)
 *******************************************************************************************************/
 bool Focuser::getSerialNumber(std::string &response)
 {
-    return m_Communication->get(MOT_NONE, "SN", response);
+    return m_Communication->get(GENERIC_NODE, "SN", response);
 }
 
 /******************************************************************************************************
@@ -346,7 +371,7 @@ bool Focuser::getSerialNumber(std::string &response)
 *******************************************************************************************************/
 bool Focuser::getVoltage12v(double &value)
 {
-    return m_Communication->getStringAsDouble(MOT_NONE, "VIN_12V", value);
+    return m_Communication->getStringAsDouble(GENERIC_NODE, "VIN_12V", value);
 }
 
 /******************************************************************************************************
@@ -355,7 +380,7 @@ bool Focuser::getVoltage12v(double &value)
 bool Focuser::getFirmwareVersion(std::string &response)
 {
     json versions;
-    if (m_Communication->get(MOT_NONE, "SWVERS", versions))
+    if (m_Communication->get(GENERIC_NODE, "SWVERS", versions))
     {
         versions["SWAPP"].get_to(response);
         return true;
@@ -363,37 +388,175 @@ bool Focuser::getFirmwareVersion(std::string &response)
     return false;
 }
 
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool Focuser::setBacklash(uint32_t steps)
+{
+    return m_Communication->set(MOT_1, {{"BKLASH", steps}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool Focuser::getBacklash(uint32_t &steps)
+{
+    return m_Communication->get(MOT_1, "BKLASH", steps);
+}
+
+
 /******************************************************************************************************
  * SestoSenso2 functions
 *******************************************************************************************************/
-SestoSenso2::SestoSenso2(const std::string &name, int port) : Focuser(name, port) {}
-bool SestoSenso2::storeAsMaxPosition()
+SestoSenso2::SestoSenso2(const std::string &name, int port) : Focuser(name, port)
+{
+}
+
+bool SestoSenso2::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
+/******************************************************************************************************
+ * Get SubModel for SestoSenso3 variants
+*******************************************************************************************************/
+bool SestoSenso2::getSubModel(std::string &submodel)
+{
+    json jsonRequest = {{"req", {{"srv", {{"GET_MODEL_SUBMODEL", ""}}}}}};
+    json jsonResponse;
+
+    if (m_Communication->sendRequest(jsonRequest, &jsonResponse))
+    {
+        try
+        {
+            std::string response;
+            jsonResponse["srv"]["GET_MODEL_SUBMODEL"].get_to(response);
+
+            // Parse: "Model = SESTOSENSO3, SubModel = SESTOSENSO3SC, ARCO = Not enabled"
+            size_t subModelPos = response.find("SubModel = ");
+            if (subModelPos != std::string::npos)
+            {
+                subModelPos += 11; // Length of "SubModel = "
+                size_t commaPos = response.find(",", subModelPos);
+                if (commaPos != std::string::npos)
+                {
+                    submodel = response.substr(subModelPos, commaPos - subModelPos);
+                }
+                else
+                {
+                    // No comma found, take until end of string
+                    submodel = response.substr(subModelPos);
+                }
+                return true;
+            }
+        }
+        catch (json::exception &e)
+        {
+            LOGF_ERROR("Error parsing submodel response: %s", e.what());
+        }
+    }
+    return false;
+}
+
+/******************************************************************************************************
+ * ===== SESTOSENSO 2 Calibration Methods =====
+*******************************************************************************************************/
+bool SestoSenso2::initCalibrationSS2()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "Init"}});
+}
+
+bool SestoSenso2::goOutToFindMaxPosSS2()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "GoOutToFindMaxPos"}});
+}
+
+bool SestoSenso2::storeAsMaxPositionSS2()
 {
     return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMaxPos"}});
 }
 
 /******************************************************************************************************
- *
+ * ===== SESTOSENSO 3 Manual Calibration Methods =====
+*******************************************************************************************************/
+bool SestoSenso2::initCalibrationSS3Manual()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "Init-Manual"}});
+}
+
+bool SestoSenso2::storeAsMaxPositionSS3Manual()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMaxPos-Manual"}});
+}
+
+/******************************************************************************************************
+ * ===== SESTOSENSO 3 Semi-Automatic Calibration Methods =====
+*******************************************************************************************************/
+bool SestoSenso2::initCalibrationSS3SemiAuto()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "Init"}});
+}
+
+bool SestoSenso2::goInToFindMinPosSS3()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "GoInToFindMinPos"}});
+}
+
+bool SestoSenso2::goOutToFindMaxPosSS3()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "GoOutToFindMaxPos"}});
+}
+
+bool SestoSenso2::stopMotorSS3()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StopMotor"}});
+}
+
+bool SestoSenso2::storeAsMaxPositionSS3SemiAuto()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMaxPos"}});
+}
+
+bool SestoSenso2::moveInSS3(uint32_t steps)
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "MoveIn-" + std::to_string(steps)}});
+}
+
+bool SestoSenso2::moveOutSS3(uint32_t steps)
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "MoveOut-" + std::to_string(steps)}});
+}
+
+/******************************************************************************************************
+ * ===== SESTOSENSO 3 SC Automatic Calibration Methods =====
+*******************************************************************************************************/
+bool SestoSenso2::startAutoCalibrationSS3SC()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "start_auto_cal"}});
+}
+
+bool SestoSenso2::stopCalibrationSS3()
+{
+    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "stop_calib"}});
+}
+
+/******************************************************************************************************
+ * ===== Shared Calibration Methods (All Models) =====
 *******************************************************************************************************/
 bool SestoSenso2::storeAsMinPosition()
 {
     return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "StoreAsMinPos"}});
 }
 
-/******************************************************************************************************
- *
-*******************************************************************************************************/
-bool SestoSenso2::goOutToFindMaxPos()
+// SestoSenso3 Recovery Delay
+bool SestoSenso2::setRecoveryDelay(int32_t delay)
 {
-    return m_Communication->command(MOT_1, {"CAL_FOCUSER", "GoOutToFindMaxPos"});
+    return m_Communication->set(GENERIC_NODE, {{"RECOVER_DELAY", delay}});
 }
 
-/******************************************************************************************************
- *
-*******************************************************************************************************/
-bool SestoSenso2::initCalibration()
+bool SestoSenso2::getRecoveryDelay(int32_t &delay)
 {
-    return m_Communication->command(MOT_1, {{"CAL_FOCUSER", "Init"}});
+    return m_Communication->get(GENERIC_NODE, "RECOVER_DELAY", delay);
 }
 
 /******************************************************************************************************
@@ -401,7 +564,7 @@ bool SestoSenso2::initCalibration()
 *******************************************************************************************************/
 bool SestoSenso2::applyMotorPreset(const std::string &name)
 {
-    return m_Communication->command(MOT_1, {{"RUNPRESET", name}});
+    return m_Communication->command(GENERIC_NODE, {{"RUNPRESET", name}});
 }
 
 /******************************************************************************************************
@@ -430,7 +593,16 @@ bool SestoSenso2::setMotorUserPreset(uint32_t index, const MotorRates &rates, co
 *******************************************************************************************************/
 bool SestoSenso2::getMotorSettings(MotorRates &rates, MotorCurrents &currents, bool &motorHoldActive)
 {
-    json jsonRequest = {{"req", {{"get", {{"MOT1", ""}}}}}};
+    json jsonRequest = {{"req", {{"get", {{"MOT1", { {"FnRUN_ACC", ""},
+                                {"FnRUN_DEC", ""}, {"FnRUN_SPD", ""}, {"FnRUN_CURR_ACC", ""},
+                                {"FnRUN_CURR_DEC", ""}, {"FnRUN_CURR_SPD", ""}, {"FnRUN_CURR_HOLD", ""}, {"HOLDCURR_STATUS", ""}
+                            }
+                        }
+                    }
+                }
+            }
+        }
+    };
     json jsonResponse;
 
     if (m_Communication->sendRequest(jsonRequest, &jsonResponse))
@@ -443,7 +615,10 @@ bool SestoSenso2::getMotorSettings(MotorRates &rates, MotorCurrents &currents, b
         jsonResponse["get"]["MOT1"]["FnRUN_CURR_DEC"].get_to(currents.decCurrent);
         jsonResponse["get"]["MOT1"]["FnRUN_CURR_SPD"].get_to(currents.runCurrent);
         jsonResponse["get"]["MOT1"]["FnRUN_CURR_HOLD"].get_to(currents.holdCurrent);
-        jsonResponse["get"]["MOT1"]["HOLDCURR_STATUS"].get_to(motorHoldActive);
+
+        int status = 0;
+        jsonResponse["get"]["MOT1"]["HOLDCURR_STATUS"].get_to(status);
+        motorHoldActive = ( status == 1 );
         return true;
     }
     return false;
@@ -510,7 +685,12 @@ bool Esatto::getBacklash(uint32_t &steps)
 *******************************************************************************************************/
 bool Esatto::getVoltageUSB(double &value)
 {
-    return m_Communication->getStringAsDouble(MOT_NONE, "VIN_USB", value);
+    return m_Communication->getStringAsDouble(GENERIC_NODE, "VIN_USB", value);
+}
+
+bool Esatto::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
 }
 
 /******************************************************************************************************
@@ -526,7 +706,7 @@ Arco::Arco(const std::string &name, int port)
 *******************************************************************************************************/
 bool Arco::setEnabled(bool enabled)
 {
-    return m_Communication->set(MOT_NONE, {{"ARCO", enabled ? 1 : 0}});
+    return m_Communication->set(GENERIC_NODE, {{"ARCO", enabled ? 1 : 0}});
 }
 
 /******************************************************************************************************
@@ -535,7 +715,7 @@ bool Arco::setEnabled(bool enabled)
 bool Arco::isEnabled()
 {
     int enabled = 0;
-    if (m_Communication->get(MOT_NONE, "ARCO", enabled))
+    if (m_Communication->get(GENERIC_NODE, "ARCO", enabled))
         return enabled == 1;
     return false;
 }
@@ -549,33 +729,17 @@ bool Arco::getAbsolutePosition(Units unit, double &value)
     switch (unit)
     {
         case UNIT_DEGREES:
-            command = {{"POSITION", "DEG"}};
+            command = {{"POSITION_DEG", ""}};
             break;
         case UNIT_ARCSECS:
-            command = {{"POSITION", "ARCSEC"}};
+            command = {{"POSITION_ARCSEC", ""}};
             break;
         case UNIT_STEPS:
-            command = {{"POSITION", "STEPS"}};
+            command = {{"POSITION_STEP", ""}};
             break;
     }
 
-
-    // For steps, we can value directly
-    if (unit == UNIT_STEPS)
-        return m_Communication->genericRequest("MOT2", "get", command, &value);
-    // For DEG and ARCSEC, a string is returned that we must parse.
-    // e.g. "10.000[DEG]"
-    else
-    {
-        std::string response;
-        if (m_Communication->genericRequest("MOT2", "get", command, &response))
-        {
-            sscanf(response.c_str(), "%lf", &value);
-            return true;
-        }
-    }
-
-    return false;
+    return m_Communication->genericRequest("MOT2", "get", command, &value);
 }
 
 /******************************************************************************************************
@@ -593,7 +757,7 @@ bool Arco::moveAbsolutePoition(Units unit, double value)
             command = {{"MOVE_ABS", {{"ARCSEC", value}}}};
             break;
         case UNIT_STEPS:
-            command = {{"MOVE_ABS", {{"STEPS", static_cast<int>(value)}}}};
+            command = {{"MOVE_ABS", {{"STEP", static_cast<int>(value)}}}};
             break;
     }
 
@@ -615,7 +779,7 @@ bool Arco::sync(Units unit, double value)
             command = {{"SYNC_POS", {{"ARCSEC", value}}}};
             break;
         case UNIT_STEPS:
-            command = {{"SYNC_POS", {{"STEPS", static_cast<int>(value)}}}};
+            command = {{"SYNC_POS", {{"STEP", static_cast<int>(value)}}}};
             break;
     }
 
@@ -698,7 +862,7 @@ bool Arco::isReversed()
 *******************************************************************************************************/
 bool Arco::getSerialNumber(std::string &response)
 {
-    return m_Communication->get(MOT_NONE, "ARCO_SN", response);
+    return m_Communication->get(GENERIC_NODE, "ARCO_SN", response);
 }
 
 /******************************************************************************************************
@@ -711,6 +875,12 @@ bool Arco::getFirmwareVersion(std::string &response)
     return true;
 }
 
+bool Arco::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
+
 /******************************************************************************************************
  *
 *******************************************************************************************************/
@@ -720,4 +890,170 @@ bool Arco::getMotorInfo(json &info)
     return m_Communication->sendRequest(jsonRequest, &info);
 }
 
+/******************************************************************************************************
+ * GIOTTO
+*******************************************************************************************************/
+GIOTTO::GIOTTO(const std::string &name, int port)
+{
+    m_Communication.reset(new Communication(name, port));
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::setLightEnabled(bool enabled)
+{
+    json jsonRequest = {{"req", {{"set", {{"LIGHT", enabled ? 1 : 0}}}}}};
+    return m_Communication->sendRequest(jsonRequest);
+}
+
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::isLightEnabled()
+{
+    int value;
+    if (m_Communication->get(GENERIC_NODE, "LIGHT", value))
+    {
+        return value == 1;
+    }
+    return false;
+}
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::getMaxBrightness(uint16_t &value)
+{
+    return m_Communication->get(GENERIC_NODE, "MAX_BRIGHTNESS", value);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::setBrightness(uint16_t value)
+{
+    return m_Communication->set(GENERIC_NODE, {{"BRIGHTNESS", value}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool GIOTTO::getBrightness(uint16_t &value)
+{
+    return m_Communication->get(GENERIC_NODE, "BRIGHTNESS", value);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+ALTO::ALTO(const std::string &name, int port)
+{
+    m_Communication.reset(new Communication(name, port));
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::getModel(std::string &model)
+{
+    return m_Communication->get(GENERIC_NODE, "MODNAME", model);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::getStatus(json &status)
+{
+    return m_Communication->get(MOT_1, "STATUS", status);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::Park()
+{
+    return setPosition(0);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::UnPark()
+{
+    return setPosition(100);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::setPosition(uint8_t value)
+{
+    return m_Communication->set(MOT_1, {{"POSITION", value}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::getPosition(uint8_t &value)
+{
+    return m_Communication->get(MOT_1, "POSITION", value);
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::stop()
+{
+    return m_Communication->command(MOT_1, {{"MOT_STOP", ""}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::initCalibration()
+{
+    return m_Communication->command(MOT_1, {{"CAL_ALTO", "Init"}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::close(bool fast)
+{
+    return m_Communication->command(MOT_1, {{"CAL_ALTO", fast ? "Close_Fast" : "Close_Slow"}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::open(bool fast)
+{
+    return m_Communication->command(MOT_1, {{"CAL_ALTO", fast ? "Open_Fast" : "Open_Slow"}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::storeClosedPosition()
+{
+    return m_Communication->command(MOT_1, {{"CAL_ALTO", "StoreAsClosedPos"}});
+}
+
+/******************************************************************************************************
+ *
+*******************************************************************************************************/
+bool ALTO::storeOpenPosition()
+{
+    return m_Communication->command(MOT_1, {{"CAL_ALTO", "StoreAsMaxOpenPos"}});
+}
+
 }
