@@ -30,7 +30,6 @@
 #include <termios.h>
 
 #define mydev           "Optec TCF-S"
-#define currentPosition FocusAbsPosN[0].value
 
 // We declare an auto pointer to TCFS.
 static std::unique_ptr<TCFS> tcfs(new TCFS());
@@ -61,24 +60,24 @@ bool TCFS::initProperties()
     {
         isTCFS3 = true;
 
-        FocusMaxPosN[0].max   = 9999;
-        FocusAbsPosN[0].max   = 9999;
-        FocusRelPosN[0].max   = 2000;
-        FocusRelPosN[0].step  = 100;
-        FocusAbsPosN[0].step  = 100;
-        FocusRelPosN[0].value = 0;
+        FocusMaxPosNP[0].setMax(9999);
+        FocusAbsPosNP[0].setMax(9999);
+        FocusRelPosNP[0].setMax(2000);
+        FocusRelPosNP[0].setStep(100);
+        FocusAbsPosNP[0].setStep(100);
+        FocusRelPosNP[0].setValue(0);
         LOG_DEBUG("TCF-S3 detected. Updating maximum position value to 9999.");
     }
     else
     {
         isTCFS3 = false;
 
-        FocusMaxPosN[0].max   = 7000;
-        FocusAbsPosN[0].max   = 7000;
-        FocusRelPosN[0].max   = 2000;
-        FocusRelPosN[0].step  = 100;
-        FocusAbsPosN[0].step  = 100;
-        FocusRelPosN[0].value = 0;
+        FocusMaxPosNP[0].setMax(7000);
+        FocusAbsPosNP[0].setMax(7000);
+        FocusRelPosNP[0].setMax(2000);
+        FocusRelPosNP[0].setStep(100);
+        FocusAbsPosNP[0].setStep(100);
+        FocusRelPosNP[0].setValue(0);
         LOG_DEBUG("TCF-S detected. Updating maximum position value to 7000.");
     }
 
@@ -112,11 +111,11 @@ bool TCFS::initProperties()
 
     // Mode parameters
     IUFillNumber(&FocusModeAN[0], "FOCUS_SLOPE_A", "Slope A", "%.0f", -999, 999, 10, 0);
-    IUFillNumber(&FocusModeAN[1], "FOCUS_INTERCEPT_A", "Intercept A", "%.0f", 0, FocusAbsPosN[0].max, 10, 0);
+    IUFillNumber(&FocusModeAN[1], "FOCUS_INTERCEPT_A", "Intercept A", "%.0f", 0, FocusAbsPosNP[0].getMax(), 10, 0);
     IUFillNumber(&FocusModeAN[2], "FOCUS_DELAY_A", "Delay A", "%.2f", 0.00, 9.99, 1.0, 0);
     IUFillNumberVector(&FocusModeANP, FocusModeAN, 3, getDeviceName(), "FOCUS_MODE_A", "Mode A", "Presets", IP_RW, 0, IPS_IDLE);
     IUFillNumber(&FocusModeBN[0], "FOCUS_SLOPE_B", "Slope B", "%.0f", -999, 999, 10, 0);
-    IUFillNumber(&FocusModeBN[1], "FOCUS_INTERCEPT_B", "Intercept B", "%.0f", 0, FocusAbsPosN[0].max, 10, 0);
+    IUFillNumber(&FocusModeBN[1], "FOCUS_INTERCEPT_B", "Intercept B", "%.0f", 0, FocusAbsPosNP[0].getMax(), 10, 0);
     IUFillNumber(&FocusModeBN[2], "FOCUS_DELAY_B", "Delay B", "%.2f", 0.00, 9.99, 1.0, 0);
     IUFillNumberVector(&FocusModeBNP, FocusModeBN, 3, getDeviceName(), "FOCUS_MODE_B", "Mode B", "Presets", IP_RW, 0, IPS_IDLE);
 
@@ -255,7 +254,7 @@ bool TCFS::Handshake()
     if (isSimulation())
     {
         LOG_INFO("TCF-S: Simulating connection.");
-        currentPosition = simulated_position;
+        FocusAbsPosNP[0].setValue(simulated_position);
         return true;
     }
     char response[TCFS_MAX_CMD] = { 0 };
@@ -412,7 +411,7 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
         // In Auto mode only FMMODE can be accepted
         // In Sleep mode only FWAKUP can be accepted
         // While focuser is moving don't allow actions other than FMMODE
-        if (!strcmp(FocusMotionSP.name, name))
+        if (FocusMotionSP.isNameMatch(name))
         {
             if (FocusModeSP.sp[0].s != ISS_ON)
             {
@@ -420,7 +419,7 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
                 return true;
             }
         }
-        if (FocusRelPosNP.s == IPS_BUSY)
+        if (FocusRelPosNP.getState() == IPS_BUSY)
         {
             LOG_WARN("The focuser is in motion. Wait until it has stopped");
             return true;
@@ -459,8 +458,8 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
                 {
                     FocusPowerSP.s = IPS_OK;
                     IDSetSwitch(&FocusPowerSP, "Focuser is set into sleep mode.");
-                    FocusAbsPosNP.s = IPS_IDLE;
-                    IDSetNumber(&FocusAbsPosNP, nullptr);
+                    FocusAbsPosNP.setState(IPS_IDLE);
+                    FocusAbsPosNP.apply();
                     //                    if (FocusTemperatureNP)
                     {
                         FocusTemperatureNP.s = IPS_IDLE;
@@ -485,8 +484,8 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
                 {
                     FocusPowerSP.s = IPS_OK;
                     IDSetSwitch(&FocusPowerSP, "Focuser is awake.");
-                    FocusAbsPosNP.s = IPS_OK;
-                    IDSetNumber(&FocusAbsPosNP, nullptr);
+                    FocusAbsPosNP.setState(IPS_OK);
+                    FocusAbsPosNP.apply();
                     //                    if (FocusTemperatureNP)
                     {
                         FocusTemperatureNP.s = IPS_OK;
@@ -507,12 +506,12 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
         // Do not process any command if focuser is asleep
         if (isConnected() && FocusPowerSP.sp[0].s == ISS_ON)
         {
-            ISwitchVectorProperty *svp = getSwitch(name);
+            auto svp = getSwitch(name);
             if (svp)
             {
-                svp->s = IPS_IDLE;
+                svp.setState(IPS_IDLE);
                 LOG_WARN("Focuser is still in sleep mode. Wake up in order to issue commands.");
-                IDSetSwitch(svp, nullptr);
+                svp.apply();
             }
             return true;
         }
@@ -599,12 +598,12 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
         // Do not process any other command if focuser is in auto mode
         if (isConnected() && FocusModeSP.sp[0].s != ISS_ON)
         {
-            ISwitchVectorProperty *svp = getSwitch(name);
+            auto svp = getSwitch(name);
             if (svp)
             {
-                svp->s = IPS_IDLE;
+                svp.setState(IPS_IDLE);
                 LOG_WARN("Focuser is in auto mode. Change to manual in order to issue commands.");
-                IDSetSwitch(svp, nullptr);
+                svp.apply();
             }
             return true;
         }
@@ -637,18 +636,18 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
             // Min
             if (!strcmp(sp->name, "FOCUS_MIN"))
             {
-                targetTicks = currentPosition;
-                MoveRelFocuser(FOCUS_INWARD, currentPosition);
+                targetTicks = FocusAbsPosNP[0].getValue();
+                MoveRelFocuser(FOCUS_INWARD, FocusAbsPosNP[0].getValue());
                 IDSetSwitch(&FocusGotoSP, "Moving focuser to minimum position...");
             }
             // Center
             else if (!strcmp(sp->name, "FOCUS_CENTER"))
             {
                 dispatch_command(FCENTR);
-                FocusAbsPosNP.s = IPS_BUSY;
-                FocusRelPosNP.s = IPS_BUSY;
-                IDSetNumber(&FocusAbsPosNP, nullptr);
-                IDSetNumber(&FocusRelPosNP, nullptr);
+                FocusAbsPosNP.setState(IPS_BUSY);
+                FocusRelPosNP.setState(IPS_BUSY);
+                FocusAbsPosNP.apply();
+                FocusRelPosNP.apply();
                 IDSetSwitch(&FocusGotoSP, "Moving focuser to center position %d...", isTCFS3 ? 5000 : 3500);
                 return true;
             }
@@ -656,9 +655,9 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
             else if (!strcmp(sp->name, "FOCUS_MAX"))
             {
                 unsigned int delta = 0;
-                delta              = FocusAbsPosN[0].max - currentPosition;
+                delta              = FocusAbsPosNP[0].getMax() - FocusAbsPosNP[0].getValue();
                 MoveRelFocuser(FOCUS_OUTWARD, delta);
-                IDSetSwitch(&FocusGotoSP, "Moving focuser to maximum position %g...", FocusAbsPosN[0].max);
+                IDSetSwitch(&FocusGotoSP, "Moving focuser to maximum position %g...", FocusAbsPosNP[0].getMax());
             }
             // Home
             else if (!strcmp(sp->name, "FOCUS_HOME"))
@@ -744,7 +743,7 @@ bool TCFS::ISNewSwitch(const char *dev, const char *name, ISState *states, char
 
 IPState TCFS::MoveAbsFocuser(uint32_t targetTicks)
 {
-    int delta = targetTicks - currentPosition;
+    int delta = targetTicks - FocusAbsPosNP[0].getValue();
     LOGF_DEBUG("Moving to absolute position %d using offset %d", targetTicks, delta);
     return MoveRelFocuser(delta < 0 ? FOCUS_INWARD : FOCUS_OUTWARD, std::abs(delta));
 }
@@ -761,7 +760,7 @@ IPState TCFS::MoveRelFocuser(FocusDirection dir, uint32_t ticks)
     // an imaging sequence. So switch to manual mode, apply the offset then return
     // to auto mode.
     targetTicks    = ticks;
-    targetPosition = currentPosition;
+    targetPosition = FocusAbsPosNP[0].getValue();
 
     TCFSMode prevMode = currentMode;
     if(currentMode != MANUAL)
@@ -785,10 +784,10 @@ IPState TCFS::MoveRelFocuser(FocusDirection dir, uint32_t ticks)
         LOGF_DEBUG("Moving outward by %d steps to position %d", targetTicks, targetPosition);
     }
 
-    FocusAbsPosNP.s = IPS_BUSY;
-    FocusRelPosNP.s = IPS_BUSY;
-    IDSetNumber(&FocusAbsPosNP, nullptr);
-    IDSetNumber(&FocusRelPosNP, nullptr);
+    FocusAbsPosNP.setState(IPS_BUSY);
+    FocusRelPosNP.setState(IPS_BUSY);
+    FocusAbsPosNP.apply();
+    FocusRelPosNP.apply();
 
     simulated_position = targetPosition;
     if(prevMode != MANUAL)
@@ -842,14 +841,14 @@ bool TCFS::dispatch_command(TCFSCommand command_type, int val, TCFSMode m)
 
         // Focuser In “nnnn”
         case FIN:
-            simulated_position = currentPosition;
+            simulated_position = FocusAbsPosNP[0].getValue();
 
             snprintf(command, TCFS_MAX_CMD, "FI%04u", targetTicks);
             break;
 
         // Focuser Out “nnnn”
         case FOUT:
-            simulated_position = currentPosition;
+            simulated_position = FocusAbsPosNP[0].getValue();
 
             snprintf(command, TCFS_MAX_CMD, "FO%04u", targetTicks);
             break;
@@ -936,7 +935,7 @@ void TCFS::TimerHit()
     char response[TCFS_MAX_CMD] = { 0 };
     // If focuser is moving wait until "*" is received
     // Then set moving indicator to OK
-    if (FocusRelPosNP.s == IPS_BUSY)
+    if (FocusRelPosNP.getState() == IPS_BUSY)
     {
         LOGF_DEBUG("%s Motion in Progress...", __FUNCTION__);
         if (read_tcfs(response, true) == false)
@@ -947,10 +946,10 @@ void TCFS::TimerHit()
         LOGF_DEBUG("%s READY %s", __FUNCTION__, response );
         if(strcmp(response, "*") == 0)
         {
-            FocusAbsPosNP.s = IPS_OK;
-            FocusRelPosNP.s = IPS_OK;
-            IDSetNumber(&FocusAbsPosNP, nullptr);
-            IDSetNumber(&FocusRelPosNP, nullptr);
+            FocusAbsPosNP.setState(IPS_OK);
+            FocusRelPosNP.setState(IPS_OK);
+            FocusAbsPosNP.apply();
+            FocusRelPosNP.apply();
 
             // If the focuser has stopped moving and auto mode is requested then
             // it is ok to set it now
@@ -1000,11 +999,11 @@ void TCFS::TimerHit()
             LOGF_DEBUG("%s Received %s", __FUNCTION__, response);
             if(sscanf(response, "P=%d", &f_position) == 1)
             {
-                currentPosition = f_position;
-                if (lastPosition != currentPosition)
+                FocusAbsPosNP[0].setValue(f_position);
+                if (lastPosition != FocusAbsPosNP[0].getValue())
                 {
-                    lastPosition = currentPosition;
-                    IDSetNumber(&FocusAbsPosNP, nullptr);
+                    lastPosition = FocusAbsPosNP[0].getValue();
+                    FocusAbsPosNP.apply();
                 }
             }
             else if(sscanf(response, "T=%f", &f_temperature) == 1)
@@ -1043,17 +1042,17 @@ void TCFS::TimerHit()
             {
                 IUResetSwitch(&FocusGotoSP);
                 FocusGotoSP.s  = IPS_OK;
-                FocusAbsPosNP.s = IPS_OK;
+                FocusAbsPosNP.setState(IPS_OK);
 
                 IDSetSwitch(&FocusGotoSP, nullptr);
-                IDSetNumber(&FocusAbsPosNP, nullptr);
+                FocusAbsPosNP.apply();
 
                 LOG_INFO("Focuser moved to center position.");
             }
         }
     }
 
-    switch (FocusAbsPosNP.s)
+    switch (FocusAbsPosNP.getState())
     {
         case IPS_OK:
             if (FocusModeSP.sp[0].s == ISS_ON)
@@ -1069,12 +1068,12 @@ void TCFS::TimerHit()
                 snprintf(response, TCFS_MAX_CMD, "P=%04d", (int)simulated_position);
 
             sscanf(response, "P=%d", &f_position);
-            currentPosition = f_position;
+            FocusAbsPosNP[0].setValue(f_position);
 
-            if (lastPosition != currentPosition)
+            if (lastPosition != FocusAbsPosNP[0].getValue())
             {
-                lastPosition = currentPosition;
-                IDSetNumber(&FocusAbsPosNP, nullptr);
+                lastPosition = FocusAbsPosNP[0].getValue();
+                FocusAbsPosNP.apply();
             }
             break;
 
@@ -1099,18 +1098,18 @@ void TCFS::TimerHit()
             if (strcmp(response, "*") == 0)
             {
                 LOGF_DEBUG("Moving focuser %d steps to position %d.", targetTicks, targetPosition);
-                FocusAbsPosNP.s = IPS_OK;
-                FocusRelPosNP.s = IPS_OK;
+                FocusAbsPosNP.setState(IPS_OK);
+                FocusRelPosNP.setState(IPS_OK);
                 FocusGotoSP.s  = IPS_OK;
-                IDSetNumber(&FocusAbsPosNP, nullptr);
-                IDSetNumber(&FocusRelPosNP, nullptr);
+                FocusAbsPosNP.apply();
+                FocusRelPosNP.apply();
                 IDSetSwitch(&FocusGotoSP, nullptr);
             }
             else
             {
-                FocusAbsPosNP.s = IPS_ALERT;
+                FocusAbsPosNP.setState(IPS_ALERT);
                 LOGF_ERROR("Unable to read response from focuser #%s#.", response);
-                IDSetNumber(&FocusAbsPosNP, nullptr);
+                FocusAbsPosNP.apply();
             }
             break;
 
